<?php
namespace App\Model\Table;

use Cake\ORM\Query;
use Cake\ORM\RulesChecker;
use Cake\ORM\Table;
use Cake\Validation\Validator;

/**
 * MasterOrganizationPositions Model
 *
 * @property \App\Model\Table\MasterOrganizationsTable|\Cake\ORM\Association\BelongsTo $MasterOrganizations
 * @property \App\Model\Table\MasterDepartmentsTable|\Cake\ORM\Association\BelongsTo $MasterDepartments
 * @property \App\Model\Table\MasterSectionsTable|\Cake\ORM\Association\BelongsTo $MasterSections
 * @property \App\Model\Table\MasterLanguagesTable|\Cake\ORM\Association\BelongsTo $MasterLanguages
 *
 * @method \App\Model\Entity\MasterOrganizationPosition get($primaryKey, $options = [])
 * @method \App\Model\Entity\MasterOrganizationPosition newEntity($data = null, array $options = [])
 * @method \App\Model\Entity\MasterOrganizationPosition[] newEntities(array $data, array $options = [])
 * @method \App\Model\Entity\MasterOrganizationPosition|bool save(\Cake\Datasource\EntityInterface $entity, $options = [])
 * @method \App\Model\Entity\MasterOrganizationPosition patchEntity(\Cake\Datasource\EntityInterface $entity, array $data, array $options = [])
 * @method \App\Model\Entity\MasterOrganizationPosition[] patchEntities($entities, array $data, array $options = [])
 * @method \App\Model\Entity\MasterOrganizationPosition findOrCreate($search, callable $callback = null, $options = [])
 *
 * @mixin \Cake\ORM\Behavior\TimestampBehavior
 */
class MasterOrganizationPositionsTable extends Table
{

    /**
     * Initialize method
     *
     * @param array $config The configuration for the Table.
     * @return void
     */
    public function initialize(array $config)
    {
        parent::initialize($config);

        $this->setTable('master_organization_positions');
        $this->setDisplayField('id');
        $this->setPrimaryKey('id');

        $this->addBehavior('Timestamp');

        $this->belongsTo('MasterOrganizations', [
            'foreignKey' => 'master_organization_id'
        ]);
        $this->belongsTo('MasterDepartments', [
            'foreignKey' => 'master_department_id'
        ]);
        $this->belongsTo('MasterSections', [
            'foreignKey' => 'master_section_id'
        ]);
        $this->belongsTo('MasterLanguages', [
            'foreignKey' => 'master_language_id'
        ]);
    }

    /**
     * Default validation rules.
     *
     * @param \Cake\Validation\Validator $validator Validator instance.
     * @return \Cake\Validation\Validator
     */
    public function validationDefault(Validator $validator)
    {
        $validator
            ->allowEmpty('id', 'create');

        $validator
            ->scalar('organization_position_name')
            ->allowEmpty('organization_position_name');

        $validator
            ->boolean('is_used')
            ->requirePresence('is_used', 'create')
            ->notEmpty('is_used');

        $validator
            ->requirePresence('created_by', 'create')
            ->notEmpty('created_by');

        $validator
            ->allowEmpty('modified_by');

        return $validator;
    }

    /**
     * Returns a rules checker object that will be used for validating
     * application integrity.
     *
     * @param \Cake\ORM\RulesChecker $rules The rules object to be modified.
     * @return \Cake\ORM\RulesChecker
     */
    public function buildRules(RulesChecker $rules)
    {
        $rules->add($rules->existsIn(['master_organization_id'], 'MasterOrganizations'));
        $rules->add($rules->existsIn(['master_department_id'], 'MasterDepartments'));
        $rules->add($rules->existsIn(['master_section_id'], 'MasterSections'));
        $rules->add($rules->existsIn(['master_language_id'], 'MasterLanguages'));

        return $rules;
    }

    /**
     * Returns the database connection name to use by default.
     *
     * @return string
     */
    public static function defaultConnectionName()
    {
        return 'db_master';
    }
}
